import { EChartOption, ECharts } from 'echarts';
import React, { RefObject, FC } from 'react';

declare const eChartEvents: {
    onClick: string;
    onDoubleClick: string;
    onMouseDown: string;
    onMouseMove: string;
    onMouseOver: string;
    onMouseOut: string;
    onGlobalOut: string;
    onContextMenu: string;
    onHighlight: string;
    onDownplay: string;
    onSelectChanged: string;
    onLegendSelectChanged: string;
    onLegendSelected: string;
    onLegendUnselected: string;
    onLegendInverseSelect: string;
    onLegendScroll: string;
    onDataZoom: string;
    onDataRangeSelected: string;
    onTimelineChanged: string;
    onTimelinePlayChanged: string;
    onRestore: string;
    onDataViewChanged: string;
    onMagicTypeChanged: string;
    onGeoSelectChanged: string;
    onGeoSelected: string;
    onGeoUnselected: string;
    onAxisAreaSelected: string;
    onFocusNodeadJacency: string;
    onUnfocusNodeAdjacency: string;
    onBrush: string;
    onBrushEnd: string;
    onBrushSelected: string;
    onGlobalCursorTaken: string;
    onRendered: string;
    onFinished: string;
};

type EChartEvents = keyof typeof eChartEvents;
type EChartEventsProps = {
    [key in EChartEvents]?: () => void;
};
type EChartInstanceOptions = {
    notMerge?: boolean;
    lazyUpdate?: boolean;
    replaceMerge?: boolean;
    silent?: boolean;
    transition?: null;
    theme?: string;
    group?: string;
    renderer?: 'svg' | 'canvas';
};
type EChartLibProps = EChartInstanceOptions & EChartOption & EChartEventsProps;
type UseEChartsProps = EChartLibProps & {
    containerRef: RefObject<HTMLDivElement>;
};

declare const useECharts: (props: UseEChartsProps) => ECharts | null;

interface EChartProps extends EChartLibProps {
    style?: React.CSSProperties;
    id?: string;
    className?: string;
    onMount?: () => unknown;
    onUnmount?: () => unknown;
    onUpdate?: () => unknown;
}
declare const EChart: FC<EChartProps>;

export { EChart, EChartEvents, EChartEventsProps, EChartInstanceOptions, EChartLibProps, EChartProps, UseEChartsProps, useECharts };
